@@ -1,6 +1,139 @@
-## 'package' can be a directory or tarball
-BiocCheck <-
-    function(package=".", checkDir = dirname(package), debug = FALSE, ...)
+#' Check a package's adherence with the Bioconductor Package Guidelines
+#'
+#' Analyzes an R package for adherence with Bioconductor package guidelines and
+#' best practices. The check outputs are categorized into ERROR, WARNING, and
+#' NOTE. See the vignette for more details. `BiocCheck` is complementary
+#' to `R CMD check`, which should always be run first.
+#'
+#' `BiocCheck()` reviews R packages for adherence with Bioconductor
+#' package guidelines and best practices. See
+#' \url{https://contributions.bioconductor.org} for the latest guidance for
+#' writing Bioconductor software. Some rationale behind these best practices
+#' can be seen in the vignette and pages in the `references` section. The
+#' vignette also provides detailed explanations of all the checks performed by
+#' `BiocCheck`.
+#'
+#' `BiocCheck` is called within R with \preformatted{ BiocCheck(<package>)
+#' } where `package` points to the source directory or the `.tar.gz`
+#' tarball that was created using `R CMD build`.
+#'
+#' \emph{Note} that `BiocCheck` is complementary to `R CMD check`.
+#' `R CMD check` should always be run first for best results.
+#'
+#' @section dot-options:
+#'
+#' \describe{
+#'   \item{new-package}{ enable checks specific to new packages}
+#'   \item{no-check-dependencies}{ disable check for bad dependencies}
+#'   \item{no-check-deprecated}{ disable check for usage of deprecated packages}
+#'   \item{no-check-remotes}{ disable check for usage of remote packages other
+#'     than those hosted on CRAN or Bioconductor}
+#'   \item{no-check-version-num}{ disable check for valid version number}
+#'   \item{no-check-R-ver}{ disable check for valid R version}
+#'   \item{no-check-pkg-size}{ disable check for package tarball size}
+#'   \item{no-check-file-size}{ disable check for individual file size}
+#'   \item{no-check-bioc-views}{ disable biocViews-specific checks (for non-BioC
+#'     packages)}
+#'   \item{no-check-bbs}{ disable BBS-specific checks (for non-BioC packages).
+#'     Valid DESCRIPTION}
+#'   \item{no-check-description}{ disable DESCRIPTION file checks}
+#'   \item{no-check-namespace}{ disable namespace checks}
+#'   \item{no-check-vignettes}{ disable vignette checks}
+#'   \item{no-check-library-calls}{ disable check usage of functions that
+#'     install or update packages}
+#'   \item{no-check-install-self}{ disable check for require or library of
+#'     itself}
+#'   \item{no-check-coding-practices}{ disable check for some common best coding
+#'     practices}
+#'   \item{no-check-function-len}{ disable check for function length}
+#'   \item{no-check-man-doc}{ disable checks for man page documentation}
+#'   \item{no-check-news}{ disable checks for NEWS file}
+#'   \item{no-check-unit-tests}{ disable checks for unit tests}
+#'   \item{no-check-skip-bioc-tests}{ disable check for tests that skip when on
+#'     bioc}
+#'   \item{no-check-formatting}{ disable checks for file formatting}
+#'   \item{no-check-CRAN}{ disable check for if package exists in CRAN}
+#'   \item{no-check-bioc-help}{ disable check for registration on Bioconductor
+#'     mailing list and support site}
+#'   \item{build-output-file}{ file containing R CMD build output, for
+#'     additional analysis}
+#'   \item{quit-with-status}{ enable exit code option when performing check}
+#' }
+#'
+#' @param package The path to an R package directory or tarball (`.tar.gz`). 
+#'   The `BiocCheck` function is intended to be run from the package
+#'   directory; therefore, the current working directory (given by `getwd()`)
+#'   is the default.
+#'
+#' @param checkDir The directory where the `BiocCheck` output directory will be
+#'   stored. By default, it will be placed in the same directory as the package
+#'   directory i.e., `dirname(pkg_dir)`.
+#'
+#' @param debug Whether to append the names of functions that correspond to
+#' each condition raised by `BiocCheck` in the written log (i.e., in the
+#' `'<package_name>.BiocCheck'` folder). This option is only relevant to
+#' developers and contributors to `BiocCheck`.
+#'
+#' @param callr logical(1) Whether to use the `callr` package to run `BiocCheck`
+#'   in an isolated R session to prevent namespace collisions.
+#'
+#' @param \dots See the details section for available options. When running
+#' `BiocCheck`, options can be specified as:
+#' \preformatted{ BiocCheck(package, `no-check-vignettes`=TRUE) }
+#'
+#' @return `BiocCheck()` is chiefly called for the side effect of the check
+#'   reporting. The function also creates a `<package_name>.BiocCheck` folder
+#'   and returns a `BiocCheck` reference class with three main list elements:
+#'
+#' \item{error}{Items to address before the package can be accepted}
+#'
+#' \item{warning}{Strongly suggested items that may require attention}
+#'
+#' \item{note}{Items to consider, though not required, before acceptance}
+#'
+#' @author Dan Tenenbaum, Lori Shepherd, and Marcel Ramos
+#'
+#' @md
+#'
+#' @references \url{https://contributions.bioconductor.org}
+#' @seealso \link{BiocCheck-class}, \link{Message-class}
+#'
+#' @importFrom utils untar
+#'
+#' @examples
+#'
+#' packageDir <- system.file("testpackages", "testpkg0", package="BiocCheck")
+#' BiocCheck(packageDir, `quit-with-status`=FALSE)
+#'
+#' @export BiocCheck
+BiocCheck <- function(
+    package = getwd(),
+    checkDir = dirname(package),
+    debug = FALSE,
+    callr = FALSE,
+    ...
+) {
+    if (callr) {
+        if (!requireNamespace("callr", quietly = TRUE))
+            stop("Install the 'callr' package to run 'BiocCheck()'",
+                 " in a separate R session")
+        callr::r(
+            function(...) { BiocCheck:::BiocCheckRun(...) },
+            args = list(
+                package = package, checkDir = checkDir, debug = debug, ...
+            ),
+            cmdargs = c("--no-echo", "--no-save", "--no-restore"),
+            show = TRUE
+        )
+    } else {
+        BiocCheckRun(
+            package = package, checkDir = checkDir, debug = debug, ...
+        )
+    }
+}
+
+BiocCheckRun <-
+    function(package, checkDir, debug, ...)
 {
     .zeroCounters()
     package <- normalizePath(package)
@@ -30,7 +163,8 @@ BiocCheck <-
     bioccheckver <- as.character(packageVersion("BiocCheck"))
     biocver <- as.character(BiocManager::version())
     checkDir <- .getBiocCheckDir(package_name, checkDir)
-    onBBS <- nzchar(Sys.getenv("BIOC_DEVEL_PASSWORD"))
+    isBBS <- Sys.getenv("IS_BIOC_BUILD_MACHINE")
+    onBBS <- nzchar(isBBS) && identical(tolower(isBBS), "true")
 
     .BiocCheck$metadata <- list(
         BiocCheckVersion = bioccheckver,
@@ -44,11 +178,6 @@ BiocCheck <-
 
     handleMessage("* Installing package...", indent = 0, exdent = 0)
     ## checks
-    if (is.null(dots[["no-check-dependencies"]])){
-        handleCheck("Checking package dependencies...")
-        checkForBadDepends(package_dir, package_name, libloc)
-    }
-
     if (is.null(dots[["no-check-deprecated"]])){
         handleCheck("Checking for deprecated package usage...")
         checkDeprecatedPackages(package_dir)
@@ -301,6 +430,7 @@ BiocCheck <-
 }
 
 .getBiocCheckDir <- function(pkgName, checkDir) {
+    checkDir <- normalizePath(checkDir, winslash = "/")
     file.path(
         checkDir, paste(pkgName, "BiocCheck", sep = ".")
     )
