@@ -1,3 +1,11 @@
+#' @importFrom tools file_path_sans_ext file_ext parse_Rd Rd2ex
+#' @importFrom utils capture.output data getParseData head packageDescription
+#'   packageVersion globalVariables readCitationFile
+#' @importFrom stringdist stringdistmatrix
+#' @importFrom knitr purl
+#' @importFrom BiocManager available install repositories version
+#' @import biocViews httr methods
+
 # Checks for BiocCheck ----------------------------------------------------
 
 checkForVersionNumberMismatch <- function(package, package_dir)
@@ -15,77 +23,6 @@ checkForVersionNumberMismatch <- function(package, package_dir)
     }
 }
 
-## Make sure this is run after pkg is installed.
-checkForBadDepends <- function(pkgdir, pkgname, lib.loc)
-{
-    pkg_desc <- packageDescription(pkgname, lib.loc = lib.loc)
-    depends <- cleanupDependency(pkg_desc$Depends)
-    depends <- append(depends, cleanupDependency(pkg_desc$Imports))
-    output <- getBadDeps(pkgdir, lib.loc = lib.loc)
-    if (is.null(output)){
-        # put these here to be consistent output messaging
-        handleCheck("Checking if other packages can import this one...")
-        handleCheck("Checking to see if we understand object initialization...")
-        return()
-    }
-
-    output <- unique(unlist(strsplit(output, "\n")))
-    output <- output[grep("no visible", output)]
-    if (length(output) == 0){
-        # put these here to be consistent output messaging
-        handleCheck("Checking if other packages can import this one...")
-        handleCheck("Checking to see if we understand object initialization...")
-        return()
-    }
-    res <- regexpr("'[^']*'", output)
-    fns <- regexpr("^[^:]*:", output)
-    if (all(res == -1L)){
-        # put these here to be consistent output messaging
-        handleCheck("Checking if other packages can import this one...")
-        handleCheck("Checking to see if we understand object initialization...")
-        return()
-    }
-
-    res <- gsub("'", "", regmatches(output, res))
-    fns <- sub(":$", "", regmatches(output, fns))
-    pkg_ns <- loadNamespace(pkgname, lib.loc = lib.loc)
-    inGlobals <- res %in% globalVariables(package = pkg_ns)
-    unloadNamespace(pkg_ns)
-    res <- res[!inGlobals]
-    fns <- fns[!inGlobals]
-
-    pkgs <- character(length(fns))
-    for (pkg in depends)
-        pkgs[res %in% getNamespaceExports(pkg)] <- pkg
-    found <- nzchar(pkgs)
-
-    handleCheck("Checking if other packages can import this one...")
-    if (any(found)) {
-        msg <- sprintf("%s::%s in %s()", pkgs[found], res[found], fns[found])
-        handleError(
-            "Packages providing ", sum(found), " object(s) used in this ",
-            "package should be imported in the NAMESPACE file, otherwise ",
-            "packages importing this package may fail.",
-            help_text = "package::object in function()",
-            messages = msg
-        )
-    }
-
-    handleCheck("Checking to see if we understand object initialization...")
-    if (!all(found)) {
-        n <- sum(!found)
-        msg <- sprintf("%s (%s)", fns[!found], res[!found])
-        handleNote(
-            "Consider clarifying how ", n, " object(s) are initialized. ",
-            "Maybe ", if (n == 1L) "it is" else "they are", " ",
-            "part of a data set loaded with data(), or perhaps part of an ",
-            "object referenced in with() or within().",
-            help_text = "function (object)",
-            messages = msg
-        )
-    }
-}
-
 checkDeprecatedPackages <- function(pkgdir)
 {
     allDepends <- getAllDependencies(pkgdir)
@@ -150,7 +87,7 @@ checkVersionNumber <- function(pkgdir)
     {
         handleError(
             "Invalid package Version, see ",
-            "http://www.bioconductor.org/developers/how-to/version-numbering/"
+            "https://contributions.bioconductor.org/versionnum.html"
         )
         return()
     }
@@ -346,13 +283,9 @@ checkBiocViews <- function(pkgdir)
     }
 
     if (packageVersion("biocViews") < package_version("1.33.9")) {
-        if (branch == "Software") {
-            branch = "software"
-        } else if (branch == "AnnotationData") {
-            branch = "annotation"
-        } else if (branch == "ExperimentData") {
-            branch = "experiment"
-        }
+        ## conditional to keep the logic the same
+        if (branch %in% c("Software", "AnnotationData", "ExperimentData"))
+            branch <- gsub("data", "", tolower(branch))
     }
 
     handleCheck("Checking for recommended biocViews...")
@@ -380,12 +313,15 @@ checkBiocViews <- function(pkgdir)
     if ("Description" %in% colnames(dcf)) {
         desc_field <- dcf[, "Description"]
         desc_words <- lengths(strsplit(desc_field, split = "[[:space:]]+"))
-        desc_sentences <- length(gregexpr("[[:alnum:] ][.!?]", desc_field)[[1]])
+        desc_sentences <- length(
+            strsplit(desc_field, split = "[.!?][[:space:]]+")[[1L]]
+        )
         msg <- "The Description field in the DESCRIPTION is made up by less
             than 3 sentences. Please consider expanding this field, and
             structure it as a full paragraph"
 
-        if (nchar(desc_field) < 50 || desc_words < 20) # values chosen sensibly in a data-driven manner
+        # values chosen sensibly in a data-driven manner
+        if (nchar(desc_field) < 50 || desc_words < 20)
             handleWarning(
                 "Description field in the DESCRIPTION file is too concise"
             )
@@ -462,7 +398,7 @@ checkBBScompatibility <- function(pkgdir, source_tarball)
     if ("Authors@R" %in% colnames(dcf))
     {
         env <- new.env(parent=emptyenv())
-        env[["c"]] = c
+        env[["c"]] <- c
         env[["person"]] <- utils::person
         pp <- parse(text=dcf[,"Authors@R"], keep.source=TRUE)
         tryCatch(people <- eval(pp, env),
@@ -487,9 +423,14 @@ checkBBScompatibility <- function(pkgdir, source_tarball)
                 validID <- .checkORCID(orcid)
                 if (!validID)
                     handleNote(
-                        "Invalid ORCID ID for ",
+                        "Invalid ORCID iD for ",
                         person$given, " ", person$family
                     )
+            } else if ("cre" %in% person$role) {
+                handleNote(
+                    "Consider adding the maintainer's ORCID iD in 'Authors@R'",
+                    " with 'comment=c(ORCID=\"...\")'"
+                )
             }
             if ("cre" %in% person$role)
             {
@@ -524,7 +465,7 @@ checkBBScompatibility <- function(pkgdir, source_tarball)
     }
     # now need to make sure that regexes work, a la python/BBS
     # I think R CMD check now does this already but can't hurt to keep
-    regex = '(.*\\S)\\s*<(.*)>\\s*'
+    regex <- '(.*\\S)\\s*<(.*)>\\s*'
     match <- regexec(regex, maintainer)[[1]]
     match.length <- attr(match, "match.length")
     if (all(match == -1) && all(match.length == -1))
@@ -618,10 +559,7 @@ checkVignetteDir <- function(pkgdir, checkingDir)
     checkVigFiles(vigdir, vigdircontents)
 
     desc <- file.path(pkgdir, "DESCRIPTION")
-    if (file.exists(desc))
-        builder <- getVigBuilder(desc)
-    else
-        builder <- NULL
+    builder <- getVigBuilder(desc)
 
     if (!is.null(builder)){
         checkVigBuilder(builder, vigdircontents)
@@ -693,7 +631,6 @@ checkVigFiles <- function(vigdir, vigdircontents){
     }
 }
 
-
 checkVigBuilder <- function(builder, vigdircontents)
 {
 # check DESCRIPTION is in at least one vignette
@@ -721,12 +658,12 @@ checkVigMetadata <- function(vigdircontents)
     badVig <- character(0)
     vigExt <- tolower(tools::file_ext(vigdircontents))
     dx <- which(vigExt != "rnw")
-    vigdircontents = vigdircontents[dx]
+    vigdircontents <- vigdircontents[dx]
     for (file in vigdircontents) {
         lines <- readLines(file, n=100L, warn=FALSE)
         idx <- grep(lines, pattern="vignette:")
         if (length(idx) == 0L)
-            badVig = c(badVig, basename(file))
+            badVig <- c(badVig, basename(file))
     }
      if (length(badVig) != 0L){
         handleWarning(
@@ -775,9 +712,9 @@ checkVigEngine <- function(builder, vigdircontents)
         }
         nadx <- which(is.na(res))
         if (length(nadx) != 0L || is.null(builder)){
-            files = res[nadx]
+            files <- res[nadx]
             if (is.null(builder))
-                files = c(files, "DESCRIPTION")
+                files <- c(files, "DESCRIPTION")
             handleError(
                 "No 'VignetteEngine' specified in vignette or DESCRIPTION. ",
                 help_text = paste(
@@ -818,11 +755,11 @@ checkVigTemplate <- function(vigdircontents)
         if (length(idx) != 0L){
             title <- tolower(gsub(".*\\{|\\}.*", "", lines[idx]))
             if (title == "vignette title"){
-                badVig = c(badVig, basename(file))
+                badVig <- c(badVig, basename(file))
             }
         }
         if (length(idx) == 0L){
-            badVig2 = c(badVig2, basename(file))
+            badVig2 <- c(badVig2, basename(file))
         }
     }
     if (length(badVig) != 0L){
@@ -859,31 +796,43 @@ checkVigChunkEval <- function(vigdircontents)
 
             # find non evaluated code chunks (```, ```r, ```R, etc.)
             # assumes every other one for start and stop of code chunk
-            nonEvalChunk <- lines[grep("^[\t >]*```+\\s*",
-                                          lines)][c(TRUE,FALSE)]
-            indx <- grep("^[\t >]*```+\\s*\\{([a-zA-Z0-9_]+.*)\\}\\s*$",
-                         nonEvalChunk)
-            if (length(indx))
-                nonEvalChunk <- nonEvalChunk[-indx]
-
+            nonEvalChunk <- lines[grep("^[\t >]*```+\\s*", lines)]
+            if (length(nonEvalChunk)) {
+                nonEvalChunk <- nonEvalChunk[c(TRUE,FALSE)]
+                indx <- grep("^[\t >]*```+\\s*\\{([a-zA-Z0-9_]+.*)\\}\\s*$",
+                             nonEvalChunk)
+                if (length(indx))
+                    nonEvalChunk <- nonEvalChunk[-indx]
+            }
         }
         chunks <- chunks + length(chunklines) + length(nonEvalChunk)
 
         efs <- efs +
-            length(grep("eval\\s?=\\s?FALSE", chunklines))
+            length(grep("eval\\s*=\\s*F(ALSE)?", chunklines))
 
         noneval <- noneval + length(nonEvalChunk)
     }
 
-    percent <- ifelse(chunks == 0 && (efs+noneval) == 0, 0, ((efs+noneval)/chunks) * (100/1))
+    totnon <- efs + noneval
+    percent <- ifelse(
+        chunks == 0 && totnon == 0,
+        0L,
+        as.integer((totnon * 100 / chunks))
+    )
 
     if (percent >= 50){
         handleWarning("Evaluate more vignette chunks.")
-        handleMessage(sprintf("# of code chunks: %s", chunks), indent=8)
-        handleMessage(sprintf("# of eval=FALSE: %s", efs), indent=8)
-        handleMessage(sprintf("# of nonexecutable code chunks by syntax: %s", noneval), indent=8)
-        handleMessage(sprintf("# total unevaluated %s (%i%%)",(efs+noneval), as.integer(percent)), indent=8)
-
+        msg <- sprintf(
+            "%s code chunks / %s total = %i%% percent unevaluated",
+            totnon,
+            chunks,
+            percent
+        )
+        handleMessage(msg, indent = 8)
+        handleMessage(
+            sprintf("%s non-exec code chunks (e.g., '``` r')", noneval),
+            indent=8
+        )
     }
 }
 
@@ -900,11 +849,14 @@ checkVigEvalAllFalse <- function(pkgdir){
     }
 }
 
+.OLD_INSTALL_CALLS <-
+    c("BiocInstaller", "biocLite", "useDevel", "biocinstallRepos")
+
 checkVigBiocInst <- function(pkgdir) {
     msg_return <- findSymbolsInVignettes(
-         pkgdir,
-         Symbols = "BiocInstaller|biocLite|useDevel|biocinstallRepos",
-         tokenTypes = c("COMMENT", "SYMBOL_FUNCTION_CALL")
+        pkgdir,
+        Symbols = .OLD_INSTALL_CALLS,
+        tokenTypes = c("COMMENT", "SYMBOL_FUNCTION_CALL")
     )
     if (length(msg_return)) {
         handleWarningFiles(
@@ -918,28 +870,22 @@ checkVigBiocInst <- function(pkgdir) {
     "update.packages", "install")
 
 checkVigInstalls <- function(pkgdir) {
-    vigdir <- file.path(pkgdir, "vignettes", "")
-    vigfiles <- getVigSources(vigdir)
-    viglist <- structure(
-        vector("list", length(vigfiles)), .Names = basename(vigfiles)
+    match_return <- findSymbolsInVignettes(
+        pkgdir,
+        Symbols = .BAD_INSTALL_CALLS,
+        tokenTypes = "SYMBOL_FUNCTION_CALL"
     )
-    for (vfile in vigfiles) {
-        tempR <- tempfile(fileext=".R")
-        knitr::purl(input = vfile, output = tempR, quiet = TRUE)
-        tokens <- getParseData(parse(tempR, keep.source = TRUE))
-        isBadCall <- tokens[, "token"] == "SYMBOL_FUNCTION_CALL" &
-            tokens[, "text"] %in% .BAD_INSTALL_CALLS
-        tokens <- tokens[isBadCall, , drop = FALSE]
-        viglist[[basename(vfile)]] <- sprintf(
-            "%s (code line %d, column %d)",
-            getDirFile(vfile), tokens[,"line1"], tokens[,"col1"]
-        )
-    }
-    viglist <- Filter(length, viglist)
-    if (length(viglist)) {
+    grep_return <- findSymbolsInVignettes(
+        pkgdir,
+        Symbols = ".*install[^ed].*",
+        tokenTypes = "SYMBOL_FUNCTION_CALL",
+        FUN = .grepTokenTextCode
+    )
+    msg_return <- c(match_return, grep_return)
+    if (length(msg_return)) {
         handleErrorFiles(
             "Installation calls found in vignette(s)",
-            messages = unlist(viglist, use.names = FALSE)
+            messages = msg_return
         )
     }
 }
@@ -970,7 +916,7 @@ checkVigClassUsage <- function(pkgdir) {
 }
 
 checkTFSymbolUsage <- function(pkgdir) {
-    viglist <- findSymbolsInVignettes(pkgdir, "^[TF]$", "SYMBOL")
+    viglist <- findSymbolsInVignettes(pkgdir, c("T", "F"), "SYMBOL")
     if (length(viglist)) {
         handleWarningFiles(
             " Avoid T/F variables; If logical, use TRUE/FALSE",
@@ -1021,24 +967,21 @@ checkIsVignetteBuilt <- function(package_dir, build_output_file)
     }
 }
 
-.BAD_INSTALL_CALLS <- c("biocLite", "install.packages", "install_packages",
-    "update.packages", "install")
-
 findSymbolsInRFiles <-
-    function(pkgdir, Symbols, tokenType, fun = TRUE)
+    function(pkgdir, Symbols, tokenType, fun = TRUE, ...)
 {
     rfiles <- getRSources(pkgdir)
     parsedCodes <- lapply(
         structure(rfiles, .Names = rfiles), parseFile, pkgdir = pkgdir
     )
     msg_res <- findSymbolsInParsedCode(
-        parsedCodes, Symbols, tokenType, fun = fun
+        parsedCodes, Symbols, tokenType, fun = fun, ...
     )
     unlist(msg_res)
 }
 
 findSymbolsInVignettes <-
-    function(pkgdir, Symbols, tokenTypes)
+    function(pkgdir, Symbols, tokenTypes, FUN = .getTokenTextCode)
 {
     vigdir <- file.path(pkgdir, "vignettes", "")
     vigfiles <- getVigSources(vigdir)
@@ -1046,7 +989,7 @@ findSymbolsInVignettes <-
     for (vfile in vigfiles) {
         tempR <- tempfile(fileext=".R")
         knitr::purl(input = vfile, output = tempR, quiet = TRUE)
-        tokens <- .grepTokenTextCode(parseFile(tempR), tokenTypes, Symbols)
+        tokens <- FUN(parseFile(tempR), tokenTypes, Symbols)
         viglist[[getDirFile(vfile)]] <- sprintf(
             "%s (code line %d, column %d)",
            getDirFile(vfile), tokens[,"line1"], tokens[,"col1"]
@@ -1154,7 +1097,7 @@ checkCodingPractice <- function(pkgdir, parsedCode, package_name)
     }
 
     # T/F
-    msg_tf <- findSymbolsInRFiles(pkgdir, c("T", "F"), "SYMBOL")
+    msg_tf <- findSymbolsInRFiles(pkgdir, c("T", "F"), "SYMBOL", lookback = "$")
     if (length(msg_tf)) {
         handleWarning(
             " Avoid T/F variables; If logical, use TRUE/FALSE ",
@@ -1225,7 +1168,7 @@ checkCodingPractice <- function(pkgdir, parsedCode, package_name)
 
     # install() / install.packages() calls
     msg_inst <- findSymbolsInRFiles(
-        pkgdir, c("install", "install.packages"), "SYMBOL_FUNCTION_CALL"
+        pkgdir, .BAD_INSTALL_CALLS, "SYMBOL_FUNCTION_CALL"
     )
     if (length(msg_inst)) {
         handleError(
@@ -1392,9 +1335,7 @@ checkSingleColon <- function(Rdir, avail_pkgs = character(0L)) {
 }
 
 .filterS3printRanges <- function(tokens) {
-    excl <- .grepSymbolRanges(
-        tokens, "^print.*", tokenType = "SYMBOL", isExp = TRUE
-    )
+    excl <- .grepSymbolRanges(tokens, "^print\\..*", tokenType = "SYMBOL")
     if (length(excl)) {
         showHits <- vapply(excl,
             function(x) "cat" %in% tokens[x, "text"], logical(1)
@@ -1415,8 +1356,9 @@ checkCatInRCode <-
     )
     parsedCodes <- lapply(parsedCodes, .filtersetMethodRanges)
     parsedCodes <- lapply(parsedCodes, .filterS3printRanges)
-    msg_res <-
-        findSymbolsInParsedCode(parsedCodes, symbols, "SYMBOL_FUNCTION_CALL")
+    msg_res <- findSymbolsInParsedCode(
+        parsedCodes, symbols, c("SYMBOL_FUNCTION_CALL", "SYMBOL")
+    )
     unlist(msg_res)
 }
 
@@ -1596,9 +1538,13 @@ checkFunctionLengths <- function(parsedCode, pkgname)
                     row['functionName'], row['filename'], row['length']
                 )
             })
+            statusmsg <- paste(
+                "There are", nrow(df), "functions greater than 50 lines."
+            )
+            statusmsg <- .singularize(df, statusmsg)
             handleNote(
-                "Recommended function length <= 50 lines.",
-                "There are ", nrow(h), " functions > 50 lines.",
+                "The recommended function length is 50 lines or less. ",
+                statusmsg,
                 help_text = "The longest 5 functions are:" ,
                 messages = fn_msg
             )
@@ -1606,6 +1552,15 @@ checkFunctionLengths <- function(parsedCode, pkgname)
     }
 }
 
+.singularize <- function(obj, message) {
+    thelen <- nrow(obj)
+    if (identical(thelen, 1L)) {
+        message <- gsub("are", "is", message)
+        message <- gsub("functions", "function", message)
+    }
+    message
+}
+
 checkManDocumentation <- function(package_dir, package_name, libloc)
 {
     # canned man prompts
@@ -1648,7 +1603,7 @@ checkForValueSection <- function(pkgdir)
     manpages <- dir(file.path(pkgdir, "man"),
         pattern="\\.Rd$", ignore.case=TRUE, full.names=TRUE)
     ok <- vapply(manpages, function(manpage) {
-        rd <- parse_Rd(manpage)
+        rd <- tools::parse_Rd(manpage)
         tags <- tools:::RdTags(rd)
 
         type <- docType(rd)
@@ -1673,9 +1628,10 @@ checkForValueSection <- function(pkgdir)
         TRUE
     }, logical(1))
     if (!all(ok)) {
+        not_oks <- vapply(manpages[!ok], getDirFile, character(1L))
         handleWarning(
             "Add non-empty \\value sections to the following man pages: ",
-            paste(getDirFile(manpages[!ok]), collapse=", "))
+            messages = paste(not_oks, collapse=", "))
     }
 }
 
@@ -1693,7 +1649,7 @@ checkExportsAreDocumented <- function(pkgdir, pkgname, lib.loc)
 
     for (manpage in manpages)
     {
-        rd <- parse_Rd(manpage)
+        rd <- tools::parse_Rd(manpage)
         name <-
             unlist(rd[unlist(lapply(rd, function(x)
                 attr(x, "Rd_tag") == "\\name"))][[1]][1])
@@ -1724,7 +1680,7 @@ checkExportsAreDocumented <- function(pkgdir, pkgname, lib.loc)
         )
     else if (length(badManPages))
         handleNote(
-            "Consider adding runnable examples to man pages that document",
+            "Consider adding runnable examples to man pages that document ",
             "exported objects.",
             messages = badManPages
         )
@@ -1742,7 +1698,7 @@ checkUsageOfDont <- function(pkgdir)
     for (dx in seq_along(manpages))
     {
         manpage <- manpages[dx]
-        rd <- parse_Rd(manpage)
+        rd <- tools::parse_Rd(manpage)
         example <- unlist(lapply(rd,
             function(x) attr(x, "Rd_tag") == "\\examples"))
         hasExamples <- any(example)
@@ -1765,17 +1721,17 @@ checkUsageOfDont <- function(pkgdir)
                 internalVec <- FALSE
             }
             if (any(donttestVec | dontrunVec) & !any(internalVec))
-                hasBad[dx] = TRUE
+                hasBad[dx] <- TRUE
 
             if (any(dontrunVec) & !any(internalVec))
-                hasdontrun[dx] = TRUE
+                hasdontrun[dx] <- TRUE
         }
     }
     if (any(hasBad)){
         perVl <- as.character(round(length(which(hasBad))/length(hasBad)*100))
         handleNoteFiles(
-            "Usage of dontrun{} / donttest{} found in man page examples.",
-            paste0(perVl, "% of man pages use one of these cases."),
+            "Usage of dontrun{} / donttest{} tags found in man page examples. ",
+            paste0(perVl, "% of man pages use at least one of these tags."),
             messages = basename(manpages)[hasBad]
         )
     }
@@ -1801,7 +1757,7 @@ checkNEWS <- function(pkgdir)
     }
     if (length(newsFnd) > 1L){
         handleNote(
-            "More than 1  NEWS file found.",
+            "More than 1  NEWS file found. ",
             "See ?news for recognition ordering.",
             help_text = "Please remove one of the following: ",
             messages = gsub(pattern=pkgdir, replacement="", newsFnd)
@@ -1841,10 +1797,6 @@ checkNEWS <- function(pkgdir)
 ## OOPS - R CMD check is looking at the INSTALLED directory
 checkUnitTests <- function(pkgdir)
 {
-    ## begin code stolen from tools:::.check_packages
-    dir.exists <- function(x) !is.na(isdir <- file.info(x)$isdir) &
-        isdir
-    ## ...
     tests_dir <- file.path(pkgdir, "tests")
     cond <- length(dir(tests_dir, pattern = "\\.(R|Rin)$"))
     if (dir.exists(tests_dir) && (!cond))
@@ -1852,7 +1804,7 @@ checkUnitTests <- function(pkgdir)
         handleError(
             "Add a .R or .Rin file in tests/ directory or unit tests will ",
             "not be run by R CMD check. See ",
-            "http://bioconductor.org/developers/how-to/unitTesting-guidelines/")
+            "https://contributions.bioconductor.org/tests.html")
         return()
     }
     if (!(dir.exists(tests_dir) && cond))
@@ -1861,7 +1813,7 @@ checkUnitTests <- function(pkgdir)
         msg <- paste0(
             "Consider adding unit tests. We strongly encourage them. See",
             "\n  ",
-            "http://bioconductor.org/developers/how-to/unitTesting-guidelines/."
+            "https://contributions.bioconductor.org/tests.html"
         )
         handleNote(msg)
     }
@@ -1897,6 +1849,15 @@ checkSkipOnBioc <- function(pkgdir)
     )
 }
 
+.rmYAMLfm <- function(lines) {
+    fm_idx <- grep("^---\\s*$", lines)
+    if (length(fm_idx) && !identical(length(fm_idx), 2L))
+        stop("More than 2 YAML front matter delimiters, i.e., '---' found")
+    if (length(fm_idx))
+        lines <- lines[-seq(fm_idx[1], fm_idx[2])]
+    lines
+}
+
 checkFormatting <- function(pkgdir, nlines=6)
 {
     pkgname <- basename(pkgdir)
@@ -1931,6 +1892,9 @@ checkFormatting <- function(pkgdir, nlines=6)
             idx <- !is.na(n) & (n > 80L)
             long <- rbind(long, Context(pkgname, file, lines, idx))
 
+            if (identical(tolower(tools::file_ext(file)), "rmd"))
+                lines <- .rmYAMLfm(lines)
+
             idx <- grepl("\t", lines)
             tab <- rbind(tab, Context(pkgname, file, lines, idx))
 
@@ -1983,7 +1947,7 @@ checkFormatting <- function(pkgdir, nlines=6)
     if (!ok)
     {
         handleMessage(
-            "See http://bioconductor.org/developers/how-to/coding-style/")
+            "See https://contributions.bioconductor.org/r-code.html")
         handleMessage(
             "See styler package: https://cran.r-project.org/package=styler ",
             "as described in the BiocCheck vignette.")
