@@ -1,7 +1,8 @@
-.printf <- function(...) cat(noquote(sprintf(...)), "\n")
-
-.debug <- function(...) if (getOption("Bioconductor.DEBUG", FALSE))
-    .printf(...)
+#' @importFrom graph nodes acc
+#' @importFrom tools Rd2ex
+#' @importFrom utils Stangle
+#' @importFrom codetools walkCode findGlobals
+NULL
 
 .msg <- function(..., appendLF=TRUE, indent=0, exdent=2)
 {
@@ -161,7 +162,7 @@ cleanupDependency <- function(input, remove.R=TRUE)
             tmp <- gsub(")", "", tmp, fixed=TRUE)
             namevec[i] <- tmp
         } else {
-            namevec[i] = ''
+            namevec[i] <- ''
         }
     }
     names(res) <- namevec
@@ -234,13 +235,10 @@ parseFile <- function(infile, pkgdir) {
     } else if (grepl("\\.Rd$", infile, TRUE)) {
         rd <- tools::parse_Rd(infile)
         outfile <- file.path(parse_dir, "parseFile.tmp")
-        code <- capture.output(Rd2ex(rd))
-        cat(code, file=outfile, sep="\n")
+        code <- capture.output(tools::Rd2ex(rd))
+        writeLines(code, con=outfile, sep="\n")
     } else if (grepl("\\.R$", infile, TRUE)) {
-        outfile <- file.path(parse_dir, "parseFile.tmp")
-        # remove empty lines before parsing
-        txt <- Filter(nzchar, readLines(infile, warn = FALSE))
-        writeLines(txt, outfile)
+        outfile <- infile
     }
     p <- parse(outfile, keep.source=TRUE)
     getParseData(p)
@@ -280,9 +278,9 @@ findSymbolInParsedCode <- function(parsedCode, pkgname, symbolName,
         }
     }
     if (token == "SYMBOL_FUNCTION_CALL")
-        parens="()"
+        parens <- "()"
     else
-        parens=""
+        parens <- ""
     for (name in names(matches))
     {
         x <- matches[[name]]
@@ -305,15 +303,20 @@ findSymbolInParsedCode <- function(parsedCode, pkgname, symbolName,
 }
 
 getDirFile <- function(fpath) {
+    if (!identical(length(fpath), 1L))
+        stop("<internal> 'fpath' input must be a scalar character")
     if (nzchar(fpath) && !is.na(fpath))
         fpath <- file.path(basename(dirname(fpath)), basename(fpath))
 
     fpath
 }
 
-.getTokenTextCode <- function(parsedf, token, text) {
+.getTokenTextCode <- function(parsedf, token, text, lookback = character(0)) {
+    cond <- parsedf$token %in% token & parsedf$text %in% text
+    if (length(lookback))
+        cond <- cond & parsedf$token[which(cond) - 1] != shQuote(lookback)
     parsedf[
-        parsedf$token %in% token & parsedf$text %in% text,
+        cond,
         c("line1", "col1", "token", "text"),
         drop = FALSE
     ]
@@ -335,11 +338,13 @@ findSymbolsInParsedCode <-
 {
     matches <- structure(vector("list", length(parsedCodeList)),
         .Names = names(parsedCodeList))
-    if (
-        !identical(length(tokenTypes), length(symbolNames)) &&
-        length(tokenTypes) == 1L
+    allcombos <- expand.grid(
+        tokenTypes = tokenTypes,
+        symbolNames = symbolNames,
+        stringsAsFactors = FALSE
     )
-        tokenTypes <- rep(tokenTypes, length(symbolNames))
+    tokenTypes <- allcombos[["tokenTypes"]]
+    symbolNames <- allcombos[["symbolNames"]]
 
     for (filename in names(parsedCodeList)) {
         df <- parsedCodeList[[filename]]
@@ -406,7 +411,7 @@ getMaintainerEmail <- function(pkgdir)
     } else if ("Authors@R" %in% colnames(dcf)) {
         ar <- dcf[, "Authors@R"]
         env <- new.env(parent=emptyenv())
-        env[["c"]] = c
+        env[["c"]] <- c
         env[["person"]] <- utils::person
         pp <- parse(text=ar, keep.source=TRUE)
         tryCatch(people <- eval(pp, env),
@@ -438,7 +443,7 @@ findLogicalFile <- function(fl) {
              error = function(err){
                  return(character())
              })
-    objs = ls(env, all.names=TRUE)
+    objs <- ls(env, all.names=TRUE)
     for (obj in objs){
       if (!is.function(env[[obj]])){
            rm(list = obj, envir = env)
@@ -466,7 +471,7 @@ findLogicalRdir <- function(pkgname, symbol){
     objs <- ls(env, all.names=TRUE)
     objs <- objs[grep("^.__[CTM]__", objs, invert=TRUE)]
     globals <- lapply(objs, function(obj) {
-        value = env[[obj]];
+        value <- env[[obj]]
         if (identical(typeof(value), "closure")) {
             findGlobals(value)
         } else character(0)
@@ -485,48 +490,6 @@ findLogicalRdir <- function(pkgname, symbol){
     }
 }
 
-makeTempRFile <- function(infile){
-    ext <- tolower(tools::file_ext(infile))
-    dir.create(tempr_dir <- tempfile())
-    outfile <- file.path(tempr_dir, paste0(basename(infile), ".R"))
-    if(ext == 'rnw' & isTRUE(vigHelper(infile, "knitr")[1])){
-        ext <- 'rmd'
-    }
-    switch(ext,
-           r = {
-               code <- readLines(infile)
-               validFile <- TRUE
-           },
-           rd = {
-               tempfile <- tools::parse_Rd(infile)
-               code <- capture.output(tools::Rd2ex(tempfile))
-               validFile <- TRUE
-           },
-           rnw = {
-               Stangle(infile, output=outfile, quiet=TRUE)
-               code <- readLines(outfile)
-               validFile <- TRUE
-           },
-           rmd = {
-               knitr::purl(input=infile, output=outfile, quiet=TRUE)
-               code <- readLines(outfile)
-               validFile = TRUE
-           },
-           {
-               validFile = FALSE
-               code <- NA
-           })
-
-    if (validFile){
-        cat("dummyTest <- function(){", file=outfile, sep="\n")
-        cat(code, file=outfile, sep="\n", append =TRUE)
-        cat("}", file=outfile, sep="\n", append =TRUE)
-        outfile
-    } else {
-        character(0)
-    }
-}
-
 grepPkgDir <- function(pkgdir, greparg, full_path=FALSE){
     args <- sprintf("%s %s*", greparg, pkgdir)
     fnd <- tryCatch(
@@ -535,17 +498,17 @@ grepPkgDir <- function(pkgdir, greparg, full_path=FALSE){
         error=function(e){character(0)})
     msg_files <- vapply(fnd,
                         FUN=function(x, pkgdir){
-                            vl = strsplit(x, split=":")
-                            filename =
+                            vl <- strsplit(x, split=":")
+                            filename <-
                                 if(full_path){
                                     vl[[1]][1]
                                 } else {
                                     sub(vl[[1]][1], pattern=pkgdir,
                                         replacement="", fixed=TRUE)
                                 }
-                            lineNum = vl[[1]][2]
+                            lineNum <- vl[[1]][2]
                             if (tolower(.Platform$OS.type) == "windows"){
-                                filename =
+                                filename <-
                                     if(full_path){
                                         paste(vl[[1]][1], vl[[1]][2], sep=":")
                                     }else {
@@ -554,7 +517,7 @@ grepPkgDir <- function(pkgdir, greparg, full_path=FALSE){
                                             pattern=pkgdir, replacement="",
                                             fixed=TRUE)
                                     }
-                                lineNum = vl[[1]][3]
+                                lineNum <- vl[[1]][3]
                             }
                             sprintf("%s (line %s)", filename, lineNum)},
                         FUN.VALUE = character(1),
@@ -591,14 +554,11 @@ getBadDeps <- function(pkgdir, lib.loc)
 
 getVigBuilder <- function(desc)
 {
-    dcf <- read.dcf(desc)
-    if (!"VignetteBuilder" %in% colnames(dcf)) {
-        builder <- NULL
-    } else {
-        builder <- strsplit(gsub(" ", "",dcf[, "VignetteBuilder"], fixed=TRUE),
-                            ",")[[1]]
-    }
-    return(builder)
+    if (file.exists(desc))
+        builder <- read.dcf(desc, fields = "VignetteBuilder")
+    else
+        builder <- NA
+    if (is.na(builder)) NULL else unlist(strsplit(builder, ",\\s+"))
 }
 
 getVigEngine <- function(vignetteFile){
@@ -660,6 +620,10 @@ getParent <- function(view, biocViewsVocab)
         v <- get(n, envir = env)
         if (typeof(v) == "closure")
             walkCode(body(v), walker)
+        else if (typeof(v) == "environment" && !walker$is_explored(v)) {
+            walker$mark_exploration(v)
+            .checkEnv(v, walker)
+        }
     }
     walker
 }
@@ -667,8 +631,11 @@ getParent <- function(view, biocViewsVocab)
 .colonWalker <- function() {
     ## record all pkg used as pkg::foo or pkg:::bar
     PKGS <- character()
+    EXPLORED_ENVIRS <- character()
     collector <- function(e, w)
         PKGS <<- append(PKGS, as.character(e[[2]]))
+    mark_exploration <- function(env)
+        EXPLORED_ENVIRS <<- append(EXPLORED_ENVIRS, format(env))
     list(handler=function(v, w) {
         switch(v, "::"=collector, ":::"=collector, NULL)
     }, call=function(e, w) {
@@ -677,7 +644,10 @@ getParent <- function(view, biocViewsVocab)
         NULL
     }, done = function() {
         sort(unique(PKGS))
-    })
+    }, is_explored = function(env) {
+       format(env) %in% EXPLORED_ENVIRS
+    }, mark_exploration = mark_exploration
+    )
 }
 
 getFunctionLengths <- function(df)
@@ -756,7 +726,7 @@ doesManPageHaveRunnableExample <- function(rd)
 
     ex <- character()
     tc <- textConnection("ex", "w", local=TRUE)
-    Rd2ex(rd, commentDontrun = TRUE, commentDonttest = TRUE, out = tc)
+    tools::Rd2ex(rd, commentDontrun = TRUE, commentDonttest = TRUE, out = tc)
     close(tc)
 
     if(!length(ex))
