@@ -1,14 +1,12 @@
-## ----eval=FALSE---------------------------------------------------------------
-#  library(BiocCheck)
-#  BiocCheck("packageDirOrTarball")
-
-## ----echo=FALSE---------------------------------------------------------------
-suppressPackageStartupMessages(library(BiocCheck))
-usage()
+## ----include=TRUE,results="hide",message=FALSE,warning=FALSE------------------
+library(BiocCheck)
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  if (!"BiocManager" %in% rownames(installed.packages()))
-#       install.packages("BiocManager")
+#  BiocCheck("<packageDirOrTarball>")
+
+## ---- eval = FALSE------------------------------------------------------------
+#  if (!require("BiocManager"))
+#      install.packages("BiocManager")
 #  BiocManager::install("BiocCheck")
 
 ## ----reformat_code, eval = FALSE----------------------------------------------
