@@ -3,24 +3,10 @@ UNIT_TEST_TEMPDIR <- file.path(tempdir(), UNIT_TEST_PKG)
 
 library(devtools)
 
-.printf <- BiocCheck:::.printf
 .zeroCounters <- BiocCheck:::.zeroCounters
 
 parsedCode <- NULL
 
-inspect <- function()
-{
-    .printf("error: %s, warning: %s, note: %s",
-        .BiocCheck$getNum("error"),
-        .BiocCheck$getNum("warning"),
-        .BiocCheck$getNum("note")
-    )
-    print(.BiocCheck$get("error"))
-    print(.BiocCheck$get("warning"))
-    print(.BiocCheck$get("note"))
-
-}
-
 create_test_package <-
     function(
         test_dir = tempfile(),
@@ -60,10 +46,12 @@ checkError <- function(msg)
     .zeroCounters()
 }
 
-checkCounter <- function(msg, type = "Error") {
+checkCounter <- function(msg, type = "error") {
     if (missing(msg))
         stop("<internal> Provide message input")
-    res <- as.integer(c("Note", "Warning", "Error") %in% type)
+    conds <- c("note", "warning", "error")
+    res <- as.integer(conds %in% type)
+    names(res) <- conds
     checkTrue(
         all(
             mapply(
@@ -117,19 +105,16 @@ test_vignettes0 <- function()
     # empty vignette dir ERROR
     dir.create(vigdir, recursive=TRUE)
     BiocCheck:::checkVignetteDir(pkgdir, TRUE)
-    checkError("No vignette sources in vignettes/ directory.")
+    checkCounter("No vignette sources in vignettes/ directory.", "error")
     .zeroCounters()
 
     # vig dir w/ source file  WARNING
     cat("nothing", file=file.path(vigdir, "test.Rnw"))
     cat("Title: unitTestTempDir", file=file.path(pkgdir, "DESCRIPTION"))
     BiocCheck:::checkVignetteDir(pkgdir, TRUE)
-    checkTrue(
-        identical(
-            .BiocCheck$getNum(c("error", "warning", "note")),
-            c(error = 0L, warning = 1L, note = 1L)
-        ),
-        "expected 1 warning and 1 note"
+    checkIdentical(
+        .BiocCheck$getNum(c("error", "warning", "note")),
+        c(error = 0L, warning = 1L, note = 1L)
     )
     .zeroCounters()
 
@@ -143,12 +128,9 @@ test_vignettes0 <- function()
         file=file.path(pkgdir, "DESCRIPTION")
     )
     BiocCheck:::checkVignetteDir(pkgdir, TRUE)
-    checkTrue(
-        identical(
-            .BiocCheck$getNum(c("error", "warning", "note")),
-            c(error = 0L, warning = 0L, note = 1L)
-        ),
-        "expected 1 note and 0 errors/warnings")
+    checkCounter(
+        "'sessionInfo' not found in vignette", "note"
+    )
     .zeroCounters()
 
 
@@ -157,12 +139,8 @@ test_vignettes0 <- function()
     dir.create(instdoc, recursive=TRUE)
     cat("nothing", file=file.path(instdoc, "test.rnw"))
     BiocCheck:::checkInstContents(pkgdir, TRUE)
-    checkTrue(
-        identical(
-            .BiocCheck$getNum(c("error", "warning", "note")),
-            c(error = 0L, warning = 1L, note = 0L)
-        ),
-        "expected 1 warning, no notes or errors"
+    checkCounter(
+        "Remove vignette sources from inst/doc", "warning"
     )
     .zeroCounters()
 
@@ -171,8 +149,9 @@ test_vignettes0 <- function()
     dir.create(instdoc, recursive=TRUE)
     cat("nothing", file=file.path(instdoc, "test.Rmd"))
     BiocCheck:::checkInstContents(pkgdir, TRUE)
-    checkTrue(.BiocCheck$getNum("warning") == 1,
-        "Rmd file not seen as valid vignette source")
+    checkCounter(
+        "Rmd file in inst/doc not seen as valid vignette source", "warning"
+    )
     unlink(file.path(instdoc, "test.Rmd"))
     .zeroCounters()
 
@@ -186,12 +165,9 @@ test_vignettes0 <- function()
         file=file.path(vigdir, "test.Rnw")
     )
     BiocCheck:::checkVignetteDir(pkgdir, TRUE)
-    checkTrue(
-        identical(
-            .BiocCheck$getNum(c("error", "warning", "note")),
-            c(error = 1L, warning = 1L, note = 1L)
-        ),
-        "expected 1 warning, note, and error."
+    checkIdentical(
+        .BiocCheck$getNum(c("error", "warning", "note")),
+        c(error = 1L, warning = 1L, note = 1L)
     )
     .zeroCounters()
 
@@ -200,13 +176,17 @@ test_vignettes0 <- function()
     unlink(file.path(pkgdir, "DESCRIPTION"))
     cat("Title: something", file=file.path(pkgdir, "DESCRIPTION"))
     BiocCheck:::checkVignetteDir(pkgdir, TRUE)
-    checkTrue(.BiocCheck$getNum("error") == 0)
-    checkTrue(.BiocCheck$getNum("note") == 1)
+    # no error if RNW
+    checkCounter("'sessionInfo' not found in vignette", "note")
+
     # check defined in desc but default vig
     unlink(file.path(pkgdir, "DESCRIPTION"))
     cat("VignetteBuilder: Sweave", file=file.path(pkgdir, "DESCRIPTION"))
     BiocCheck:::checkVignetteDir(pkgdir, TRUE)
-    checkTrue(.BiocCheck$getNum("error") == 0)
+    checkIdentical(
+        .BiocCheck$getNum(c("error", "warning", "note")),
+        c(error = 0L, warning = 1L, note = 1L)
+    )
     .zeroCounters()
 
     # check vignette style of example package
@@ -297,7 +277,7 @@ test_checkNewPackageVersionNumber <- function()
     BiocCheck:::checkNewPackageVersionNumber(UNIT_TEST_TEMPDIR)
     checkCounter(
         "New package x version non-zero",
-        "Warning"
+        "warning"
     )
 
     setVersion("00.99.3")
@@ -308,7 +288,7 @@ test_checkNewPackageVersionNumber <- function()
     BiocCheck:::checkNewPackageVersionNumber(UNIT_TEST_TEMPDIR)
     checkCounter(
         "New package y version not 99",
-        "Error"
+        "error"
     )
 
     setVersion("0.99.1")
@@ -448,7 +428,7 @@ test_checkBBScompatibility <- function()
     BiocCheck:::.checkDescription(desc)
     checkCounter(
         "Description field in the DESCRIPTION file is too concise",
-        "Warning"
+        "warning"
     )
 
 
@@ -463,7 +443,7 @@ test_checkBBScompatibility <- function()
     BiocCheck:::.checkDescription(file.path(UNIT_TEST_TEMPDIR, "DESCRIPTION"))
     checkCounter(
         "The Description field in the DESCRIPTION is less than two sentences",
-        "Note"
+        "note"
     )
 
     cat("Package: Foo",
@@ -557,7 +537,7 @@ test_checkBBScompatibility <- function()
     BiocCheck:::checkBBScompatibility(UNIT_TEST_TEMPDIR, FALSE)
     checkTrue(
         .BiocCheck$getNum("note") == 1L,
-        "An invalid ORCID ID causes a note!"
+        "An invalid ORCID iD causes a note!"
     )
 
     .zeroCounters()
@@ -585,7 +565,11 @@ test_checkBBScompatibility <- function()
         sep = "\n",
         file=file.path(UNIT_TEST_TEMPDIR, "DESCRIPTION"))
     BiocCheck:::checkBBScompatibility(UNIT_TEST_TEMPDIR, FALSE)
-    checkError("More than one maintainer doesn't cause error!")
+    # ERROR: More than one maintainer & NOTE: Include ORCID iD
+    checkIdentical(
+        .BiocCheck$getNum(c("error", "warning", "note")),
+        c(error = 1L, warning = 0L, note = 1L)
+    )
 
     .zeroCounters()
     cat(paste("Package:", UNIT_TEST_PKG),
@@ -598,7 +582,7 @@ test_checkBBScompatibility <- function()
         sep = "\n",
         file=file.path(UNIT_TEST_TEMPDIR, "DESCRIPTION"))
     BiocCheck:::checkBBScompatibility(UNIT_TEST_TEMPDIR, FALSE)
-    checkTrue(stillZero())
+    checkCounter("Include ORCID iD", "note")
 
     .zeroCounters()
     dir.create(file.path(UNIT_TEST_TEMPDIR,"inst"))
@@ -795,7 +779,7 @@ test_checkCatInRCode <- function()
     msg <- BiocCheck:::checkCatInRCode(
         Rdir, c("cat", "print")
     )
-    checkTrue(length(msg) == 8)
+    checkTrue(length(msg) == 9)
 }
 
 test_checkEqInAssignment <- function()
@@ -816,6 +800,7 @@ test_checkVigInstalls <- function()
         )
     )
     checkEqualsNumeric(.BiocCheck$getNum("error"), 1)
+    checkEqualsNumeric(length(.BiocCheck$get("error")[[1]]), 5)
     .zeroCounters()
 }
 
@@ -998,24 +983,6 @@ test_checkImportSuggestions <- function()
     }
 }
 
-test_checkForBadDepends <- function()
-{
-    .zeroCounters()
-    pkg <- system.file("testpackages", "testpkg0", package="BiocCheck")
-    inst_path <- BiocCheck:::installAndLoad(pkg)
-    BiocCheck:::checkForBadDepends(
-        pkgdir = pkg,
-        pkgname = "testpkg0",
-        lib.loc = file.path(inst_path, "lib")
-    )
-    checkEqualsNumeric(1, BiocCheck:::.BiocCheck$getNum("error"))
-    checkEqualsNumeric(1, BiocCheck:::.BiocCheck$getNum("note"))
-    checkTrue(grepl("providing 1 object", BiocCheck:::.BiocCheck$get("error")))
-    checkTrue(
-        grepl("how [0-9] object", BiocCheck:::.BiocCheck$get("note"))
-    )
-}
-
 test_remotesUsage <- function()
 {
     pkg <- system.file("testpackages", "testpkg0", package="BiocCheck")
@@ -1408,7 +1375,7 @@ test_checkUsageOfDont <- function()
     .zeroCounters()
 }
 
-test_IsOrcidIdValid = function()
+test_IsOrcidIdValid <- function()
 {
     orcid <- c(
         "0000-0001-6197-3471",
@@ -1421,3 +1388,67 @@ test_IsOrcidIdValid = function()
     valid <- c(TRUE, TRUE, FALSE, FALSE, FALSE, FALSE)
     checkIdentical(valid, BiocCheck:::.checkORCID(orcid))
 }
+
+test_getBiocCheckDir <- function() {
+    getBiocCheckDir <- BiocCheck:::.getBiocCheckDir
+    pkg <- system.file(
+        "testpackages", "testpkg0", package="BiocCheck"
+    )
+    checkIdentical(
+        getBiocCheckDir(basename(pkg), dirname(pkg)),
+        file.path(dirname(pkg), paste(basename(pkg), "BiocCheck", sep = "."))
+    )
+}
+
+test_getDirFile <- function() {
+    getDirFile <- BiocCheck:::getDirFile
+    vigfile <- system.file(
+        "testpackages", "testpkg0", "vignettes", "evalfalse.Rmd",
+        package="BiocCheck"
+    )
+    checkIdentical("vignettes/evalfalse.Rmd", getDirFile(vigfile))
+
+    vigfiles <- list.files(
+        system.file(
+            "testpackages", "testpkg0", "vignettes", package="BiocCheck"
+        ),
+        full.names = TRUE
+    )
+    checkException(getDirFile(vigfiles))
+}
+
+
+test_checkEnv <- function() {
+    # Simple function in empty environment:
+    env <- new.env(parent = emptyenv())
+    env$f <- function() BiocCheck::BiocCheck
+    dcolon <- BiocCheck:::.checkEnv(env, BiocCheck:::.colonWalker())$done()
+    checkIdentical(dcolon, "BiocCheck")
+
+    # Function inside environment inside environment
+    # This happens on pkg ns environments with S4 methods
+    env <- new.env(parent = emptyenv())
+    env$another <- new.env(parent = emptyenv())
+    env$another$f <- function() BiocCheck::BiocCheck
+    dcolon <- BiocCheck:::.checkEnv(env, BiocCheck:::.colonWalker())$done()
+    checkIdentical(dcolon, "BiocCheck")
+
+    # Environments can contain themselves. Check that this does not
+    # lead to an infinite loop
+    env <- new.env(parent = emptyenv())
+    env$another <- env
+    env$another$f <- function() BiocCheck::BiocCheck
+    dcolon <- BiocCheck:::.checkEnv(env, BiocCheck:::.colonWalker())$done()
+    checkIdentical(dcolon, "BiocCheck")
+
+    # Environments can contain other envs that can contain the first env.
+    # Check that this does not lead to an infinite loop
+    env <- new.env(parent = emptyenv())
+    env$another <- new.env(parent = emptyenv())
+    env$another$env2 <- env
+    env$another$env2$f <- function() BiocCheck::BiocCheck
+    dcolon <- BiocCheck:::.checkEnv(env, BiocCheck:::.colonWalker())$done()
+    checkIdentical(dcolon, "BiocCheck")
+}
+
+
